@@ -69,7 +69,7 @@ class NaPoleonBinanceFutureBot(object):
             'timestamp': timestamp,
             'startTime': startTime,
             'endTime': endTime,
-            'limit':30
+            'limit':300
 
         }
         query_string = urllib.parse.urlencode(params)
@@ -135,6 +135,7 @@ class NaPoleonBinanceFutureBot(object):
 
         params = {
             'symbol': asset,
+            'type' : 1,
             'recvWindow': 60000,
             'timestamp': timestamp,
             'startTime': startTime,
@@ -239,7 +240,7 @@ class NaPoleonBinanceFutureBot(object):
         endTime = int(end_time.timestamp() * 1000)
 
         BASE_URL = 'https://api.binance.com'
-        PATH = '/sapi/v1/futures/data/topLongShortPositionRatio'
+        PATH = '/sapi/v1/futures/transfer'
 
 
         headers = {
