@@ -128,10 +128,11 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
         ts8 = ts7 - 2001 * 3600 * 24
 
         print('Loading data')
-        day_url_request = 'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym='+ssj_against+'&e='+exchange+'&toTs={}&limit=2000'
+        day_url_request = 'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym='+ssj_against+'&toTs={}&limit=2000'
         dataframe = None
         for me_timestamp in [ts8,ts7,ts6,ts5,ts4,ts3,ts2,ts1,ts]:
             print('waiting')
+            time.sleep(1)
             df = request_day_data_paquet(day_url_request, me_timestamp, ssj)
             if df is not None:
                 if dataframe is not None:
@@ -282,7 +283,9 @@ def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_
         ts18 = ts17 - 2001 * 3600
 
         print('Loading data')
-        hours_url_request = 'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=' + ssj_against + '&e=' + exchange + '&toTs={}&limit=2000'
+        #hours_url_request = 'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=' + ssj_against + '&e=' + exchange + '&toTs={}&limit=2000'
+        hours_url_request = 'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=' + ssj_against + '&toTs={}&limit=2000'
+
         dataframe = None
         for me_timestamp in [ts18, ts17, ts16, ts15, ts14, ts13, ts12, ts11, ts10, ts9, ts8, ts7, ts6, ts5, ts4, ts3, ts2, ts1, ts]:
             print('waiting')
