@@ -8,7 +8,7 @@ from napoleontoolbox.file_saver import dropbox_file_saver
 
 
 class EnsemblingParalleLauncher():
-    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', ss=[10], ns=[21], low_bounds=[0.], up_bounds = [0.2]):
+    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', ss=[10], ns=[21], low_bounds=[0.], up_bounds = [0.2], leverages =[1.]):
         self.args = []
         self.counter = 1
         self.seed = 0
@@ -16,8 +16,9 @@ class EnsemblingParalleLauncher():
             for n in ns:
                 for low_bound in low_bounds:
                     for up_bound in up_bounds:
-                        self.args.append((self,self.seed,  n, s, low_bound, up_bound))
-                        self.counter = self.counter + 1
+                        for leverage in leverages:
+                            self.args.append((self,self.seed,  n, s, low_bound, up_bound, leverage))
+                            self.counter = self.counter + 1
         self.args.sort()
         self.local_root_directory = local_root_directory
         self.user = user
