@@ -169,6 +169,55 @@ def generate_lead_lag(lookback_windows, lead_lags, contravariants, ):
                     })
     return parameters
 
+def generate_dd_threshold_lo_without_lag(lookback_windows, up_thresholds):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for up_threshold in up_thresholds:
+                parameters.append({
+                    'lookback_window':lookback_window,
+                    'up_threshold':up_threshold,
+                })
+    return parameters
+
+def generate_dd_threshold_ls_without_lag(lookback_windows, low_thresholds, up_thresholds):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for up_threshold in up_thresholds:
+            for low_threshold in low_thresholds:
+                parameters.append({
+                    'lookback_window':lookback_window,
+                    'up_threshold':up_threshold,
+                    'low_threshold':low_threshold
+                })
+    return parameters
+
+
+def generate_looklag_pente(lookback_windows, lags, pente_windows):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for lag in lags:
+            for pente_window in pente_windows:
+                if lag <= int(lookback_window / 2.):
+                    if pente_window <= int(lookback_window/lag):
+                        parameters.append({
+                            'lookback_window': lookback_window,
+                            'lag': lag,
+                            'pente_window':pente_window
+                        })
+    return parameters
+
+def generate_looklag(lookback_windows, lags):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for lag in lags:
+            if lag <= int(lookback_window / 2.):
+                parameters.append({
+                    'lookback_window': lookback_window,
+                    'lag': lag
+                })
+
+    return parameters
+
 def generate_dd_threshold_lo(lookback_windows, up_thresholds, lags, contravariants):
     parameters = []
     for lookback_window in lookback_windows:
