@@ -671,6 +671,8 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     ohlc_bnb_min_binance.index = ohlc_bnb_min_binance.index.tz_localize(None)
 
     def filter_me_month(data_df, filtering_month):
+        if filtering_month == 0:
+            filtering_month=12
         if 'Date' not in data_df.columns:
             data_df['Date'] = pd.to_datetime(data_df.index)
         data_df['month'] = data_df['Date'].dt.month
