@@ -730,6 +730,7 @@ def fetch_all_necessary_data_b40_xbt(public_key = None, private_key= None, start
     ##########
     ##############################
     ##############################
+
     print('usdt change rate fetched')
     print(ohlc_usdt_day_cc.shape)
 
@@ -806,12 +807,16 @@ def fetch_all_necessary_data_b40_xbt(public_key = None, private_key= None, start
     x.columns = [y + '_btc_cc' for y in x.columns]
     ohlc_btc_cc = x.copy()
 
+    wholeWalletHist = walletHist.copy()
+    wholeWalletHist = wholeWalletHist.set_index('timestamp')
+    wholeWalletHist.index = wholeWalletHist.index.tz_localize(None)
+    wholeWalletHist['walletBalance_xbt'] = wholeWalletHist.walletBalance / 100000000
+    wholeWalletHist['amount_xbt'] = wholeWalletHist.amount / 100000000
+
     walletHist = walletHist.set_index('timestamp')
     walletHist.index = walletHist.index.map(lambda x: x.floor('60s'))
     walletHist = walletHist[~walletHist.index.duplicated(keep='first')].sort_index(ascending=True)
     walletHist.index = walletHist.index.tz_localize(None)
-
-
     walletHist['walletBalance_xbt'] = walletHist.walletBalance / 100000000
 
 
@@ -828,8 +833,16 @@ def fetch_all_necessary_data_b40_xbt(public_key = None, private_key= None, start
 #    walletHist = pd.merge(walletHist, ohlc_usdt_day_cc, left_index = True, right_index = True)
     walletHist = pd.merge(walletHist, ohlc_btc_cc['close_btc_cc'], left_index=True, right_index=True)
     #walletHist['open_btc_cc'] = walletHist['open_btc_cc'].bfill()
-
     walletHist['walletBalance_usd'] = walletHist.walletBalance_xbt * walletHist.close_btc_cc
+
+    wholeWalletHist['date'] = pd.to_datetime(wholeWalletHist.index)
+    wholeWalletHist['date'] = wholeWalletHist.apply(compute_signal_effective_date, axis=1)
+    wholeWalletHist.index = wholeWalletHist['date']
+    #    walletHist = pd.merge(walletHist, ohlc_usdt_day_cc, left_index = True, right_index = True)
+    wholeWalletHist = pd.merge(wholeWalletHist, ohlc_btc_cc['close_btc_cc'], left_index=True, right_index=True)
+    # walletHist['open_btc_cc'] = walletHist['open_btc_cc'].bfill()
+    wholeWalletHist['walletBalance_usd'] = wholeWalletHist.walletBalance_xbt * wholeWalletHist.close_btc_cc
+
     ########################################################################
     ########################################################################
     ################### gettingn the proper trades df
@@ -913,9 +926,13 @@ def fetch_all_necessary_data_b40_xbt(public_key = None, private_key= None, start
         walletHist_df = walletHist_df[walletHist_df.index <= maxDate].copy()
     else :
         walletHist_df = walletHist.copy()
-    walletHist_df['Date'] = walletHist_df.index
+        wholeWalletHist_df = wholeWalletHist.copy()
 
+    walletHist_df['Date'] = walletHist_df.index
     walletHist_df = walletHist_df.sort_values(by = 'Date')
+
+    wholeWalletHist_df['Date'] = wholeWalletHist_df.index
+    wholeWalletHist_df = wholeWalletHist_df.sort_values(by = 'Date')
     #######
 
 
@@ -946,6 +963,15 @@ def fetch_all_necessary_data_b40_xbt(public_key = None, private_key= None, start
       #  'close':'rate_usdt_usd'
     })
 
+    wholeWalletHist_df = wholeWalletHist_df.rename(columns = {
+        'walletBalance_xbt':'wallet_balance_btc',
+        'walletBalance_usd': 'wallet_balance_usd',
+        'close_btc_cc':'btc_price',
+      #  'close':'rate_usdt_usd'
+    })
+
+
+
     valo_columns=[
         'Date',
         'btc_price',
@@ -1010,7 +1036,7 @@ def fetch_all_necessary_data_b40_xbt(public_key = None, private_key= None, start
 
     summary_df = summary_df.reset_index()
 
-    return filtered_bitmex_df,filWal,wal,actual_positions, funding_df, summary_df
+    return filtered_bitmex_df,filWal,wal,actual_positions, funding_df, summary_df, wholeWalletHist_df
 
 
 
@@ -1873,6 +1899,8 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
         'total_fees_usd'] = df.trading_fees_xbt_usd + df.trading_fees_eth_usd + df.funding_fees_xbt_usd + df.funding_fees_eth_usd
 
     print('Grouping by...')
+    
+
     td = df[['dt_floor', 'traded_eth', 'traded_xbt', 'size_eth', 'size_xbt', 'sens_trade_eth', 'sens_trade_xbt',
              'funding_fees_xbt_usd', 'funding_fees_eth_usd',
              'trading_fees_xbt_btc', 'trading_fees_xbt_usd', 'trading_fees_eth_btc', 'trading_fees_eth_usd',
